/*
 *  Copyright (C) 2012-2017 Texas Instruments Incorporated
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */
/**
 *  \file   mcspiSample_io.c
 *
 *  \brief  McSPI evm to evm communication sample application
 *
 *          This file demonstrates the use of Mcspi by using an
 *          EVM to EVM communication setup.This file configures one of the evm
 *          in master mode.
 */

/* ========================================================================== */
/*                          INCLUDE FILES                                     */
/* ========================================================================== */

#include <stdio.h>
#include <string.h>
#include <xdc/std.h>
#include <ti/sysbios/io/GIO.h>
#include <ti/sysbios/BIOS.h>
#include <xdc/runtime/Error.h>
#include <xdc/runtime/System.h>
#include <ti/sysbios/knl/Task.h>
#include <xdc/runtime/IHeap.h>
#include <ti/sysbios/heaps/HeapMem.h>
#include <ti/drv/bsp_lld/mcspi/bsp_mcspi.h>
#include <xdc/runtime/Memory.h>
#include <ti/sdo/edma3/drv/edma3_drv.h>
#include <xdc/std.h>
#include <stdio.h>
#include <ti/sysbios/BIOS.h>
#include <ti/sysbios/io/GIO.h>
#include <ti/sysbios/io/IOM.h>
#include <xdc/runtime/Log.h>
#include <ti/sysbios/knl/Task.h>
#include <ti/sysbios/heaps/HeapMem.h>
#include <xdc/runtime/Error.h>
#include <xdc/runtime/System.h>
#include <ti/sdo/edma3/drv/edma3_drv.h>
#include <ti/drv/vps/include/common/bsp_types.h>
#include <ti/drv/vps/include/common/trace.h>
#include <ti/drv/vps/include/common/bsp_config.h>
#include <ti/drv/vps/include/common/bsp_utils.h>
#include <ti/drv/vps/include/common/bsp_common.h>
#include <ti/drv/bsp_lld/mcspi/bsp_mcspi.h>
#include <ti/drv/vps/include/platforms/bsp_platform.h>
#include <ti/drv/vps/include/boards/bsp_board.h>
#include <ti/drv/vps/include/devices/bsp_device.h>
#include <ti/drv/bsp_lld/i2c/bsp_i2c.h>
#include <ti/drv/vps/include/fvid2/fvid2.h>
#include <ti/drv/vps/examples/utility/bsputils_mem.h>
#include <ti/drv/vps/examples/utility/bsputils_prf.h>
#include <ti/drv/vps/examples/utility/bsputils_app.h>
#include <src/rtos/utils_common/include/utils_dma.h>
#include "mcspiSample_io.h"

/* ========================================================================== */
/*                          LOCAL FUNCTION PROTOTYPES                         */
/* ========================================================================== */
EDMA3_DRV_Handle edma3init(UInt32 edma3Id, EDMA3_DRV_Result *);
Int32 App_mcspiDefaultInit(UInt32 isI2cInitReq);
void SPI_init(void);
/* ========================================================================== */
/*                            MACRO DEFINITONS                                */
/* ========================================================================== */

/* ========================================================================== */
/*                              GLOBAL VARIABLES                              */
/* ========================================================================== */

EDMA3_DRV_Handle      gEdmaHandle;
UInt32       gIsI2cInitReq;
extern const IOM_Fxns Mcspi_IOMFXNS;
HeapMem_Handle myHeap;
//static I2c_DevInitParams gI2cDevInitParams[BSP_DEVICE_I2C_INST_ID_MAX];

/*
 * Buffers placed in external memory are aligned on a 128 bytes boundary.
 * In addition, the buffer should be of a size multiple of 128 bytes for
 * the cache to work optimally.
 */

#define BUFLEN          (1024 * 4) /* Buffer size */
#define BUFALIGN        128        /* Alignment of buffer for use of L2 cache */
#define ITERATION_CNT   100        /* Number of Iterations */
#define NUM_BUFS        3          /* Num Bufs to be issued and reclaimed */

/* handle to the input and output streams   */
GIO_Handle mcspiHandle = NULL;

/* Global SPI init config data structure    */
Mcspi_Params   mcspiPrms;

Mcspi_DataParam       issueDataparam[NUM_BUFS];

/* Buffer alignement is required when working in DMA Mode */
#pragma DATA_ALIGN(rxbuf, BUFALIGN);
Ptr  rxbuf[NUM_BUFS];

/* Buffer alignement is required when working in DMA Mode */
#pragma DATA_ALIGN(txbuf, BUFALIGN);
Ptr  txbuf[NUM_BUFS];

Bool failFlag = FALSE;

/* Function prototype */
//#if 0
static void createStream(void);
static void prime(void);
//#endif
/* ========================================================================== */
/*                           FUNCTION DEFINITIONS                             */
/* ========================================================================== */

/*
 * ======== createStream ========
 */
//#if 0
static void createStream(void)
{
    GIO_Params       ioParams;
    Mcspi_ChanParams chanParams;
    Error_Block      eb;

    Error_init(&eb);

    /*
     * Initialize channel attributes.
     */
    GIO_Params_init(&ioParams);

    /* update the edma Handle                                                 */
    chanParams.hEdma = gEdmaHandle;
    chanParams.chipSelTimeControl = MCSPI_CLK_CYCLE0;
    chanParams.fifoEnable         = (UInt32) TRUE;
    chanParams.spiChipSelectHold  = (UInt32) TRUE;
    chanParams.chanNum = 0;

    /* If cross bar events are being used then make isCrossBarIntEn = TRUE and
     * choose appropriate interrupt number to be mapped (assign it to
     * intNumToBeMapped)
     */
    /* Cross bar evt disabled */
    chanParams.crossBarEvtParam.isCrossBarIntEn  = (UInt32) FALSE;
    chanParams.crossBarEvtParam.intNumToBeMapped = 0xFF;  /* Invalid number */

    ioParams.chanParams = (Ptr) & chanParams;
    ioParams.model      = GIO_Model_ISSUERECLAIM;
    ioParams.numPackets = NUM_BUFS + 1;

    mcspiHandle = GIO_create("/mcspi0", GIO_INOUT, &ioParams, &eb);
    if (mcspiHandle == NULL)
    {
        System_printf("\r\nCreate input stream FAILED.\r\n");
        BIOS_exit(0);
    }
    System_printf("\r\nCreate input stream completed.\r\n");
}
//#endif
/*
 * \brief   Function to submit request the driver.Depending on the macro
 *          "NUM_BUFS" either the driver can be buffered with multiple requests
 *          or only one buffer by using the NUM_BUFS as 1.
 *
 * \param   None
 *
 * \return  None
 */
//#if 0
static void prime(void)
{

    Error_Block  eb;
    Int32        count = 0;
    IHeap_Handle iheap;
    UInt32       tempCount = 0;
    UInt32       size      = 0;
    Int          status    = IOM_COMPLETED;

    iheap = HeapMem_Handle_to_xdc_runtime_IHeap(myHeap);
    Error_init(&eb);

    /* Allocate buffers for the GIO buffer exchanges                          */
    for (count = 0; count < (NUM_BUFS); count++)
    {
        rxbuf[count] = (Ptr) Memory_calloc(iheap, BUFLEN, BUFALIGN, &eb);
        if (NULL == rxbuf[count])
        {
            System_printf("\r\nMEM_calloc failed.\r\n");
        }

        txbuf[count] = (Ptr) Memory_calloc(iheap, BUFLEN, BUFALIGN, &eb);
        if (NULL == txbuf[count])
        {
            System_printf("\r\nMEM_calloc failed.\r\n");
        }
    }

    /* Fill the buffers with known data and transmit the same and check if the*
     * same pattern is received on the other EVM                              */
    for (count = 0; count < (NUM_BUFS); count++)
    {
        for (tempCount = 0; tempCount < BUFLEN; tempCount++)
        {
            ((Uint8 *) txbuf[count])[tempCount] = tempCount;
        }
    }
    for (count = 0; count < NUM_BUFS; count++)
    {
        issueDataparam[count].bufLen    = BUFLEN;
        issueDataparam[count].inBuffer  = rxbuf[count];
        issueDataparam[count].outBuffer = txbuf[count];

        size = issueDataparam[count].bufLen;

        /* Issue the first & second empty buffers to the input stream         */
        status = GIO_issue(mcspiHandle, &issueDataparam[count], size, NULL);

        if (status != IOM_PENDING && status != IOM_COMPLETED)
        {
            System_printf("\r\nsatus =%d\r\n",status);
            System_printf("\r\nFailed to issue empty buffer to stream\r\n");
        }
    }
    System_printf("\r\nprime completed\r\n");
}
//#endif
void spiSampleTask(void)
{
      Int32 retVal = FVID2_SOK;
      Bsp_PlatformInitParams platInitPrms;

    /* isPinMuxSettingReq parameter will be initialised to TRUE */
    BspPlatformInitParams_init(&platInitPrms);
//
    platInitPrms.isAllMcSPIInitReq  = TRUE;
    platInitPrms.isPinMuxSettingReq = TRUE;

    /* Initialize pinmux and evm related configurations */
    Bsp_platformInit(&platInitPrms);
    /* System init */
    gIsI2cInitReq = FALSE;
    retVal       = App_mcspiDefaultInit(gIsI2cInitReq);
    if (retVal != FVID2_SOK)
    {
        System_printf("Error: : System Init Failed!!!\r\n");
    }
    /* Set the pin Mux */
    Bsp_boardSetPinMux(BSP_DRV_ID_MCSPI, BSP_DEVICE_MCSPI_INST_ID_0,
                       BSP_BOARD_MODE_DEFAULT);
//    Bsp_boardSetPinMux(BSP_DRV_ID_MCSPI, BSP_DEVICE_MCSPI_INST_ID_1,
//                       BSP_BOARD_MODE_DEFAULT);

    /* Set the board muxes */
    Bsp_boardSelectDevice(BSP_DRV_ID_MCSPI, BSP_DEVICE_MCSPI_INST_ID_0);
//    Bsp_boardSelectDevice(BSP_DRV_ID_MCSPI, BSP_DEVICE_MCSPI_INST_ID_1);
    /* call the function for the SPI application test                     */

//    start_spi_sample();
//
//    App_mcspiDefaultDeInit(gIsI2cInitReq);
//
//    /* Start the Heart Beat Print                                         */
//    tskHeartBeat();
//
//    return;
}

/*
 * \brief   This function demostrates the use of Mcspi using an EVM to EVM
 *          communication setup.
 *
 * \param   None
 *
 * \return  None
 */
void start_spi_sample_new(Void)
{
    System_printf("\r\nIn start SPI sample new\r\n");
    volatile Int32   i32Count  = 0;

    Mcspi_DataParam *dataparam = {0};
    UInt32           tempCount = 0;
    UInt32           i, loopcount = 0;
    UInt32           dataMismatchError = 0;
    UInt8            temp8InBufVal = 0, temp8OutBufVal = 0;
    UInt16           temp16InBufVal = 0, temp16OutBufVal = 0;
    UInt32           temp32InBufVal = 0, temp32OutBufVal = 0;
    UInt32           maskVal        = 0;

    Int status = IOM_COMPLETED;
//    Sleep(1000);
    spiSampleTask();
//    createStream();
    SPI_init();

//    EDMA3_DRV_Result edmaResult = 0;
    Utils_dmaInit();
    gEdmaHandle = Utils_dmaGetEdma3Hndl(0);
//    gEdmaHandle = edma3init(0, &edmaResult);

    if (gEdmaHandle != NULL)
    {
        /* Report EDMA Error */
        System_printf("\r\nEDMA driver initialization FAIL\r\n");
    }
    else
    {
        System_printf("\r\nEDMA driver initialization PASS.\r\n");
    }

    /* Call createStream function to create I/O streams                       */
    createStream();

    /* Call prime function to do priming                                      */
    prime();
//#if 0
    for (i = 0; i < NUM_BUFS; i++)
    {
        dataparam = NULL;
        /* Reclaim full buffer from the stream                                */
        System_printf("before the reclaim \r\n");
        status = GIO_issue(mcspiHandle, &issueDataparam[0], BUFLEN, NULL);
        System_printf("status of GIO_issue =%d\r\n",status);
        status = GIO_reclaim(mcspiHandle, (Ptr *) &dataparam, NULL, NULL);
        System_printf("In for loop\r\n");
        if (IOM_COMPLETED != status)
        {
            System_printf("Iteration %d\r\n", i32Count);

            System_printf(
                "Error reclaiming empty buffer from the streams %x"
                " error = 0x%d\r\n",
                ((Uint8) (dataparam->outBuffer[i32Count])),
                status);
            break;
        }

        maskVal =
            ((1 << (mcspiPrms.spiHWCfgData.configChfmt[0].charLength)) - 1);

        for (tempCount = 0; tempCount < BUFLEN; )
        {
            if (mcspiPrms.spiHWCfgData.configChfmt[0].charLength <= 8)
            {
                temp8InBufVal  = dataparam->inBuffer[tempCount];
                temp8OutBufVal = dataparam->outBuffer[tempCount];

                /* temp8OutBufVal & temp8InBufVal is to be aligned with
                 * charLength.
                 * temp8InBufVal alignment is required only in case of DMA Mode
                 */
                if ((temp8OutBufVal & maskVal) != (temp8InBufVal & maskVal))
                {
                    dataMismatchError = 1;
                    break;
                }
                tempCount++;
            }
            else if (mcspiPrms.spiHWCfgData.configChfmt[0].charLength <= 16)
            {
                temp16InBufVal = dataparam->inBuffer[tempCount] +
                                 (dataparam->inBuffer[tempCount + 1] << 8);
                temp16OutBufVal = dataparam->outBuffer[tempCount] +
                                  (dataparam->outBuffer[tempCount + 1] << 8);

                /* temp16OutBufVal & temp16InBufVal is to be aligned with
                 * charLength.
                 * temp16InBufVal alignment is required only in case of DMA Mode
                 */
                if ((temp16OutBufVal & maskVal) != (temp16InBufVal & maskVal))
                {
                    dataMismatchError = 1;
                    break;
                }
                tempCount = tempCount + 2;
            }
            else if (mcspiPrms.spiHWCfgData.configChfmt[0].charLength <= 32)
            {
                temp32InBufVal = dataparam->inBuffer[tempCount] +
                                 (dataparam->inBuffer[tempCount + 1] << 8) +
                                 (dataparam->inBuffer[tempCount + 2] << 16) +
                                 (dataparam->inBuffer[tempCount + 3] << 24);
                temp32OutBufVal = dataparam->inBuffer[tempCount] +
                                  (dataparam->inBuffer[tempCount + 1] << 8) +
                                  (dataparam->inBuffer[tempCount + 2] << 16) +
                                  (dataparam->inBuffer[tempCount + 3] << 24);

                /* temp32OutBufVal & temp32InBufVal is to be aligned with
                 * charLength
                 * temp32InBufVal alignment is required only in case of DMA Mode
                 */
                if ((temp32OutBufVal & maskVal) != (temp32InBufVal & maskVal))
                {
                    dataMismatchError = 1;
                    break;
                }
                tempCount = tempCount + 4;
            }
            else
            {
                System_printf("Invalid Word Length\r\n");
            }
        }
    }
    if (dataMismatchError == 0)
    {
        System_printf("Loop back test passed\r\n");
        System_printf(
            "\r\nRunning McSpi read in a loop to probe and verify the signals\r\n");
    }
    else
    {
        System_printf("Loop back test Failed\r\n");
        System_printf(
            "Error matching data in Buffer no: %d at location %d\r\n", i,
            tempCount);
        while (1) ;
    }
    /* Forever loop to continously recevie and transmit data            */
    for (loopcount = 0;; loopcount++)
    {
        status = GIO_issue(mcspiHandle, &issueDataparam[0], BUFLEN, NULL);
        if (status != IOM_PENDING && status != IOM_COMPLETED)
        {
            System_printf("\r\nFailed to issue empty buffer to stream\r\n");
        }
        status = GIO_reclaim(mcspiHandle, (Ptr *) &dataparam, NULL, NULL);
        if (IOM_COMPLETED != status)
        {
            System_printf("\r\nError In reclaim in continuous loop\r\n");
        }
        if (loopcount % 100 == 0)
        {
            System_printf(".\r\n");
        }
    }
//#endif
}

void user_mcspi_init(void)
{
  //  Int32 opMode;
    Mcspi_init();

//    mcspiPrms = Mcspi_PARAMS;
//    System_printf("Please Connect the McSPI%d MISO (DAT0) to MOSI (DAT1)\r\n",
//                  (inst_num + 1U));
//    System_printf(
//        "And then enter the Operating mode\r\n0 - Polled Mode\
//            \r\n1 - Interrupt Mode\
//            \r\n2 - DMA Interrupt mode\r\n$>");
////    scanf("%d", &opMode);
//    if (opMode == 0)
//    {
        mcspiPrms.opMode = MCSPI_OPMODE_POLLED;
//    }
//    else if (opMode == 1)
//    {
//        mcspiPrms.opMode = MCSPI_OPMODE_INTERRUPT;
//    }
//    else if (opMode == 2)
//    {
//        mcspiPrms.opMode = MCSPI_OPMODE_DMAINTERRUPT;
//    }
//    else
//    {
//        mcspiPrms.opMode = MCSPI_OPMODE_POLLED;
//    }

    mcspiPrms.instNum         = 0;
    mcspiPrms.hwiNumber       = 7;
    mcspiPrms.enableCache     = (UInt32) TRUE;
    mcspiPrms.edma3EventQueue = 0;
    mcspiPrms.enableErrIntr   = (UInt32) FALSE;

    mcspiPrms.spiHWCfgData.masterOrSlave         = MCSPI_COMMMODE_MASTER;
    mcspiPrms.spiHWCfgData.singleOrMultiChEnable = MCSPI_SINGLE_CHANNEL;
    mcspiPrms.spiHWCfgData.pinOpModes    = MCSPI_PINOPMODE_4PIN;
    mcspiPrms.spiHWCfgData.fifoRxTrigLvl = 32;
    mcspiPrms.spiHWCfgData.fifoTxTrigLvl = 32;
    mcspiPrms.spiHWCfgData.configChfmt[0].charLength = MCSPI_LEN_8BIT;
    mcspiPrms.spiHWCfgData.configChfmt[0].multiWordAccessEnable =
        (UInt32) FALSE;
    mcspiPrms.spiHWCfgData.configChfmt[0].spiChipSelectEnablePol =
        (UInt32) FALSE;
    mcspiPrms.spiHWCfgData.configChfmt[0].clockMode           = MCSPI_MODE0;
    mcspiPrms.spiHWCfgData.configChfmt[0].clockRatioExtension = 0;
    mcspiPrms.spiHWCfgData.configChfmt[0].spiWordInitDelay    = MCSPI_NO_DELAY;
    mcspiPrms.spiHWCfgData.configChfmt[0].trasmitReceiveMode  = MCSPI_BOTH_RXTX;
    mcspiPrms.spiHWCfgData.configChfmt[0].granularityEnable   = (UInt32) TRUE;
    mcspiPrms.spiHWCfgData.configChfmt[0].busFreq             = 1000000;
    mcspiPrms.spiHWCfgData.configChfmt[0].spienHighPolarity   = (UInt32) FALSE;
    mcspiPrms.spiHWCfgData.configChfmt[0].slaveModeChipSelect = MCSPI_SPIEN_0;
    mcspiPrms.spiHWCfgData.configChfmt[0].spiDat0Dir          = MCSPI_IN;
    mcspiPrms.spiHWCfgData.configChfmt[0].spiDat1Dir          = MCSPI_OUT;

    if (MCSPI_OPMODE_POLLED == mcspiPrms.opMode)
    {
        System_printf("\r\nMcspi is configured in polled mode\r\n");
    }
    else if (MCSPI_OPMODE_INTERRUPT == mcspiPrms.opMode)
    {
        System_printf("\r\nMcspi is configured in interrupt mode\r\n");
    }
    else if (MCSPI_OPMODE_DMAINTERRUPT == mcspiPrms.opMode)
    {
        System_printf("\r\nMcspi is configured in dma mode\r\n");
    }
    else
    {
        System_printf("\r\nError: unknown mode of operation!!!!!!!!!!\r\n");
    }
}
void SPI_init(void)
{
System_printf("Running McSPI Loopback test.\r\n");
//    System_printf(
//        "Enter McSPI instance on which test to be run\
//        \r\n0 - McSPI1 instance\r\n1 - McSPI2 instance\r\n$>");
//    scanf("%d", &inst_num);
//    if (inst_num != 0 && inst_num != 1)
//    {
//        inst_num = 0;
//    }
    GIO_addDevice("/mcspi0", (xdc_Ptr) & Mcspi_IOMFXNS, &user_mcspi_init,
                  0U, (xdc_Ptr) & mcspiPrms);
}

Int32 App_mcspiDefaultInit(UInt32 isI2cInitReq)
{
    Int32  retVal = BSP_SOK;
    //UInt32 instCnt;
    Bsp_CommonInitParams    commonInitPrms;
    Bsp_BoardInitParams     boardInitPrms;
    Bsp_PlatformInitParams  platInitPrms;
    //Bsp_DeviceInitParams    deviceInitPrms;
    //lld_hsi2c_initParam_t   i2cInitParams[BSP_DEVICE_I2C_INST_ID_MAX];
    //const Bsp_BoardI2cData *i2cData;
    //Bsp_BoardI2cInstData   *i2cInstData;
    BspCommonInitParams_init(&commonInitPrms);
    retVal += Bsp_commonInit(&commonInitPrms);
    if (BSP_SOK != retVal)
    {
        GT_0trace(BspAppTrace, GT_ERR, "Error: BSP Common Init failed!!\r\n");
    }

    BspBoardInitParams_init(&boardInitPrms);
    /* Override board detection if I2C is disabled */
    if (((Bool) TRUE) != ((Bool) isI2cInitReq))
    {
        boardInitPrms.boardId      = BSP_BOARD_UNKNOWN;
        boardInitPrms.baseBoardRev = BSP_BOARD_REV_UNKNOWN;
        boardInitPrms.dcBoardRev   = BSP_BOARD_REV_UNKNOWN;
    }
    retVal += Bsp_boardInit(&boardInitPrms);
    if (BSP_SOK != retVal)
    {
        GT_0trace(BspAppTrace, GT_ERR, "Error: Board Init failed!!\r\n");
    }

    BspPlatformInitParams_init(&platInitPrms);
    retVal += Bsp_platformInit(&platInitPrms);
    if (BSP_SOK != retVal)
    {
        GT_0trace(BspAppTrace, GT_ERR, "Error: Platform Init failed!!\r\n");
    }

    retVal += Fvid2_init(NULL);
    if (BSP_SOK != retVal)
    {
        GT_0trace(BspAppTrace, GT_ERR, "Error: FVID2 Init failed!!\r\n");
    }

    /* Override I2C init for non-EVM builds */
    if (BSP_PLATFORM_ID_EVM != Bsp_platformGetId())
    {
        isI2cInitReq = FALSE;
    }

   /* if (((Bool) TRUE) == ((Bool) isI2cInitReq))
    {
        i2cData = Bsp_boardGetI2cData();
        GT_assert(BspAppTrace, (NULL != i2cData));
        GT_assert(BspAppTrace,
                  (i2cData->numInst <= BSP_DEVICE_I2C_INST_ID_MAX));
        GT_assert(BspAppTrace, (NULL != i2cData->instData));

        for (instCnt = 0U; instCnt < i2cData->numInst; instCnt++)
        {
            i2cInstData = &i2cData->instData[instCnt];
            GT_assert(BspAppTrace,
                      (i2cInstData->instId < BSP_DEVICE_I2C_INST_ID_MAX));
            i2cInitParams[instCnt].opMode       = HSI2C_OPMODE_INTERRUPT;
            i2cInitParams[instCnt].isMasterMode = TRUE;
            i2cInitParams[instCnt].is10BitAddr  = FALSE;
            i2cInitParams[instCnt].i2cBusFreq   =
                (lld_i2c_busspeed) i2cInstData->busClkKHz;
            i2cInitParams[instCnt].i2cIntNum      = i2cInstData->intNum;
            i2cInitParams[instCnt].i2cOwnAddr     = 0xCC;
            gI2cDevInitParams[instCnt].initParams = &i2cInitParams[instCnt];
            gI2cDevInitParams[instCnt].hsi2c_sem  =
                BspOsal_semCreate((Int32) 1, (Bool) TRUE);
            gI2cDevInitParams[instCnt].instId = i2cInstData->instId;
        }

        if (i2cData->numInst > 0)
        {
            retVal = I2c_GlobalInit(i2cData->numInst, &gI2cDevInitParams[0U]);
            if (BSP_SOK != retVal)
            {
                GT_0trace(BspAppTrace, GT_ERR, "Error: I2C Init failed!!\r\n");
            }
        }

        BspDeviceInitParams_init(&deviceInitPrms);
        deviceInitPrms.isI2cProbingReq = FALSE;
        retVal += Bsp_deviceInit(&deviceInitPrms);
        if (BSP_SOK != retVal)
        {
            GT_0trace(BspAppTrace, GT_ERR, "Error: Device Init failed!!\r\n");
        }
    }*/

    /*retVal += BspUtils_memInit();
    if (BSP_SOK != retVal)
    {
        GT_0trace(BspAppTrace, GT_ERR, "Error: App MEM Utils Init failed!!\r\n");
    }

    retVal += BspUtils_prfInit();
    if (BSP_SOK != retVal)
    {
        GT_0trace(BspAppTrace, GT_ERR, "Error: App PRF Utils Init failed!!\r\n");
    }*/

    retVal += BspUtils_appInit();
    if (BSP_SOK != retVal)
    {
        GT_0trace(BspAppTrace, GT_ERR, "Error: App Utils Init failed!!\r\n");
    }

    /* Print BSP version string and platform info*/
    GT_0trace(BspAppTrace, GT_INFO, " \r\n");
    GT_2trace(BspAppTrace, GT_INFO,
              " Build time            : [%s %s]\r\n", __TIME__, __DATE__);
    GT_1trace(BspAppTrace, GT_INFO,
              " BSP Version           : [%s]\r\n", Bsp_getVersionString());
    Bsp_platformPrintInfo();
    Bsp_boardPrintInfo();
    GT_0trace(BspAppTrace, GT_INFO, " \r\n");

    return (retVal);
}
